@@ -1,5 +1,5 @@
 /* This file is part of GNU Pies.
-   Copyright (C) 2007-2016 Sergey Poznyakoff
+   Copyright (C) 2007-2019 Sergey Poznyakoff
 
    GNU Pies is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -711,7 +711,7 @@ ctlio_finalize_reply (struct ctlio *io)
 
   ctlio_printf (io, "HTTP/1.1 %3d %s", io->code, http_text (io->code));
   ctlio_eol (io);
-  grecs_symtab_enumerate (io->output.headers, format_header, io);
+  grecs_symtab_foreach (io->output.headers, format_header, io);
   ctlio_eol (io);
   
   ctlbuf_copy (&io->obuf, &tmpbuf);
@@ -1453,7 +1453,9 @@ static char * const pies_comp_mode_str[] = {
   [pies_comp_exec]         = "exec",        
   [pies_comp_accept]       = "accept",       
   [pies_comp_inetd]        = "inetd",        
-  [pies_comp_pass_fd]      = "pass_fd",      
+  [pies_comp_pass_fd]      = "pass_fd",
+  [pies_comp_startup]      = "startup",
+  [pies_comp_shutdown]     = "shutdown",
   [pies_comp_wait]         = "wait",          
   [pies_comp_once]         = "once",         
   [pies_comp_boot]         = "boot",         
